==> glpi-11.0.1.tgz: glpi/src/Glpi/Form/AccessControl/FormAccessParameters.php <==
<?php

/**
 * ---------------------------------------------------------------------
 *
 * GLPI - Gestionnaire Libre de Parc Informatique
 *
 * http://glpi-project.org
 *
 * @copyright 2015-2025 Teclib' and contributors.
 * @copyright 2003-2014 by the INDEPNET Development Team.
 * @licence   https://www.gnu.org/licenses/gpl-3.0.html
 *
 * ---------------------------------------------------------------------
 *
 * LICENSE
 *
 * This file is part of GLPI.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * ---------------------------------------------------------------------
 */

namespace Glpi\Form\AccessControl;

use Glpi\Session\SessionInfo;

final readonly class FormAccessParameters
{
    public function __construct(
        private ?SessionInfo $session_info = null,
        private array $url_parameters = [],
        private bool $bypass_restriction = false,
    ) {}

    public function isAuthenticated()
    {
        return $this->session_info !== null;
    }

    public function getSessionInfo(): ?SessionInfo
    {
        return $this->session_info;
    }

    public function getUrlParameters(): array
    {
        return $this->url_parameters;
    }

    public function isBypassingRestrictions(): bool
    {
        return $this->bypass_restriction;
    }
}

==> glpi-11.0.4.tgz: glpi/src/Glpi/Form/AccessControl/FormAccessParameters.php <==
<?php

/**
 * ---------------------------------------------------------------------
 *
 * GLPI - Gestionnaire Libre de Parc Informatique
 *
 * http://glpi-project.org
 *
 * @copyright 2015-2025 Teclib' and contributors.
 * @copyright 2003-2014 by the INDEPNET Development Team.
 * @licence   https://www.gnu.org/licenses/gpl-3.0.html
 *
 * ---------------------------------------------------------------------
 *
 * LICENSE
 *
 * This file is part of GLPI.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * ---------------------------------------------------------------------
 */

namespace Glpi\Form\AccessControl;

use Glpi\Session\SessionInfo;

final readonly class FormAccessParameters
{
    public function __construct(
        private ?SessionInfo $session_info = null,
        private array $url_parameters = [],
        private bool $bypass_restriction = false,
    ) {}

    public function isAuthenticated(): bool
    {
        return $this->session_info !== null;
    }

    public function getSessionInfo(): ?SessionInfo
    {
        return $this->session_info;
    }

    public function getUrlParameters(): array
    {
        return $this->url_parameters;
    }

    public function isBypassingRestrictions(): bool
    {
        return $this->bypass_restriction;
    }
}
